Class: Google::Apis::FileV1beta1::AcquireShareResponse
- Inherits:
-
Object
- Object
- Google::Apis::FileV1beta1::AcquireShareResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/file_v1beta1/classes.rb,
lib/google/apis/file_v1beta1/representations.rb,
lib/google/apis/file_v1beta1/representations.rb
Overview
Output message for AcquireShare.
Instance Attribute Summary collapse
-
#ip_address ⇒ String
The IP address of the physical Filestore instance hosting the share.
-
#share_id ⇒ String
The specific share identifier on the instance.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AcquireShareResponse
constructor
A new instance of AcquireShareResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AcquireShareResponse
Returns a new instance of AcquireShareResponse.
65 66 67 |
# File 'lib/google/apis/file_v1beta1/classes.rb', line 65 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ip_address ⇒ String
The IP address of the physical Filestore instance hosting the share.
Corresponds to the JSON property ipAddress
58 59 60 |
# File 'lib/google/apis/file_v1beta1/classes.rb', line 58 def ip_address @ip_address end |
#share_id ⇒ String
The specific share identifier on the instance.
Corresponds to the JSON property shareId
63 64 65 |
# File 'lib/google/apis/file_v1beta1/classes.rb', line 63 def share_id @share_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
70 71 72 73 |
# File 'lib/google/apis/file_v1beta1/classes.rb', line 70 def update!(**args) @ip_address = args[:ip_address] if args.key?(:ip_address) @share_id = args[:share_id] if args.key?(:share_id) end |