Class: Google::Apis::FileV1beta1::Backup
- Inherits:
-
Object
- Object
- Google::Apis::FileV1beta1::Backup
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/file_v1beta1/classes.rb,
lib/google/apis/file_v1beta1/representations.rb,
lib/google/apis/file_v1beta1/representations.rb
Overview
A Filestore backup.
Instance Attribute Summary collapse
-
#capacity_gb ⇒ Fixnum
Output only.
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
A description of the backup with 2048 characters or less.
-
#download_bytes ⇒ Fixnum
Output only.
-
#file_system_protocol ⇒ String
Output only.
-
#kms_key_name ⇒ String
Immutable.
-
#labels ⇒ Hash<String,String>
Resource labels to represent user provided metadata.
-
#name ⇒ String
Output only.
-
#satisfies_pzi ⇒ Boolean
(also: #satisfies_pzi?)
Output only.
-
#satisfies_pzs ⇒ Boolean
(also: #satisfies_pzs?)
Output only.
-
#source_file_share ⇒ String
Name of the file share in the source Filestore instance that the backup is created from.
-
#source_instance ⇒ String
The resource name of the source Filestore instance, in the format
projects/project_id/locations/location_id/instances/instance_id``, used to create this backup. -
#source_instance_tier ⇒ String
Output only.
-
#state ⇒ String
Output only.
-
#storage_bytes ⇒ Fixnum
Output only.
-
#tags ⇒ Hash<String,String>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Backup
constructor
A new instance of Backup.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Backup
Returns a new instance of Backup.
176 177 178 |
# File 'lib/google/apis/file_v1beta1/classes.rb', line 176 def initialize(**args) update!(**args) end |
Instance Attribute Details
#capacity_gb ⇒ Fixnum
Output only. Capacity of the source file share when the backup was created.
Corresponds to the JSON property capacityGb
83 84 85 |
# File 'lib/google/apis/file_v1beta1/classes.rb', line 83 def capacity_gb @capacity_gb end |
#create_time ⇒ String
Output only. The time when the backup was created.
Corresponds to the JSON property createTime
88 89 90 |
# File 'lib/google/apis/file_v1beta1/classes.rb', line 88 def create_time @create_time end |
#description ⇒ String
A description of the backup with 2048 characters or less. Requests with longer
descriptions will be rejected.
Corresponds to the JSON property description
94 95 96 |
# File 'lib/google/apis/file_v1beta1/classes.rb', line 94 def description @description end |
#download_bytes ⇒ Fixnum
Output only. Amount of bytes that will be downloaded if the backup is restored
Corresponds to the JSON property downloadBytes
99 100 101 |
# File 'lib/google/apis/file_v1beta1/classes.rb', line 99 def download_bytes @download_bytes end |
#file_system_protocol ⇒ String
Output only. The file system protocol of the source Filestore instance that
this backup is created from.
Corresponds to the JSON property fileSystemProtocol
105 106 107 |
# File 'lib/google/apis/file_v1beta1/classes.rb', line 105 def file_system_protocol @file_system_protocol end |
#kms_key_name ⇒ String
Immutable. KMS key name used for data encryption.
Corresponds to the JSON property kmsKeyName
110 111 112 |
# File 'lib/google/apis/file_v1beta1/classes.rb', line 110 def kms_key_name @kms_key_name end |
#labels ⇒ Hash<String,String>
Resource labels to represent user provided metadata.
Corresponds to the JSON property labels
115 116 117 |
# File 'lib/google/apis/file_v1beta1/classes.rb', line 115 def labels @labels end |
#name ⇒ String
Output only. The resource name of the backup, in the format projects/
project_id/locations/location_id/backups/backup_id`.
Corresponds to the JSON propertyname`
121 122 123 |
# File 'lib/google/apis/file_v1beta1/classes.rb', line 121 def name @name end |
#satisfies_pzi ⇒ Boolean Also known as: satisfies_pzi?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzi
126 127 128 |
# File 'lib/google/apis/file_v1beta1/classes.rb', line 126 def satisfies_pzi @satisfies_pzi end |
#satisfies_pzs ⇒ Boolean Also known as: satisfies_pzs?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzs
132 133 134 |
# File 'lib/google/apis/file_v1beta1/classes.rb', line 132 def satisfies_pzs @satisfies_pzs end |
#source_file_share ⇒ String
Name of the file share in the source Filestore instance that the backup is
created from.
Corresponds to the JSON property sourceFileShare
139 140 141 |
# File 'lib/google/apis/file_v1beta1/classes.rb', line 139 def source_file_share @source_file_share end |
#source_instance ⇒ String
The resource name of the source Filestore instance, in the format projects/
project_id/locations/location_id/instances/instance_id`, used to create
this backup.
Corresponds to the JSON propertysourceInstance`
146 147 148 |
# File 'lib/google/apis/file_v1beta1/classes.rb', line 146 def source_instance @source_instance end |
#source_instance_tier ⇒ String
Output only. The service tier of the source Filestore instance that this
backup is created from.
Corresponds to the JSON property sourceInstanceTier
152 153 154 |
# File 'lib/google/apis/file_v1beta1/classes.rb', line 152 def source_instance_tier @source_instance_tier end |
#state ⇒ String
Output only. The backup state.
Corresponds to the JSON property state
157 158 159 |
# File 'lib/google/apis/file_v1beta1/classes.rb', line 157 def state @state end |
#storage_bytes ⇒ Fixnum
Output only. The size of the storage used by the backup. As backups share
storage, this number is expected to change with backup creation/deletion.
Corresponds to the JSON property storageBytes
163 164 165 |
# File 'lib/google/apis/file_v1beta1/classes.rb', line 163 def storage_bytes @storage_bytes end |
#tags ⇒ Hash<String,String>
Optional. Input only. Immutable. Tag key-value pairs bound to this resource.
Each key must be a namespaced name and each value a short name. Example: "
123456789012/environment" : "production", "123456789013/costCenter" : "
marketing" See the documentation for more information: - Namespaced name:
https://cloud.google.com/resource-manager/docs/tags/tags-creating-and-managing#
retrieving_tag_key - Short name: https://cloud.google.com/resource-manager/
docs/tags/tags-creating-and-managing#retrieving_tag_value
Corresponds to the JSON property tags
174 175 176 |
# File 'lib/google/apis/file_v1beta1/classes.rb', line 174 def @tags end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 |
# File 'lib/google/apis/file_v1beta1/classes.rb', line 181 def update!(**args) @capacity_gb = args[:capacity_gb] if args.key?(:capacity_gb) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @download_bytes = args[:download_bytes] if args.key?(:download_bytes) @file_system_protocol = args[:file_system_protocol] if args.key?(:file_system_protocol) @kms_key_name = args[:kms_key_name] if args.key?(:kms_key_name) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi) @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs) @source_file_share = args[:source_file_share] if args.key?(:source_file_share) @source_instance = args[:source_instance] if args.key?(:source_instance) @source_instance_tier = args[:source_instance_tier] if args.key?(:source_instance_tier) @state = args[:state] if args.key?(:state) @storage_bytes = args[:storage_bytes] if args.key?(:storage_bytes) @tags = args[:tags] if args.key?(:tags) end |