Class: Google::Apis::FileV1beta1::CloudFilestoreService
- Inherits:
-
Core::BaseService
- Object
- Core::BaseService
- Google::Apis::FileV1beta1::CloudFilestoreService
- Defined in:
- lib/google/apis/file_v1beta1/service.rb
Overview
Cloud Filestore API
The Cloud Filestore API is used for creating and managing cloud file servers.
Constant Summary collapse
- DEFAULT_ENDPOINT_TEMPLATE =
"https://file.$UNIVERSE_DOMAIN$/"
Instance Attribute Summary collapse
-
#key ⇒ String
API key.
-
#quota_user ⇒ String
Available to use for quota purposes for server-side applications.
Instance Method Summary collapse
-
#cancel_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FileV1beta1::Empty
Starts asynchronous cancellation on a long-running operation.
-
#create_project_location_backup(parent, backup_object = nil, backup_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FileV1beta1::Operation
Creates a backup.
-
#create_project_location_instance(parent, instance_object = nil, instance_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FileV1beta1::Operation
Creates an instance.
-
#create_project_location_instance_share(parent, share_object = nil, share_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FileV1beta1::Operation
Creates a share.
-
#create_project_location_instance_snapshot(parent, snapshot_object = nil, snapshot_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FileV1beta1::Operation
Creates a snapshot.
-
#delete_project_location_backup(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FileV1beta1::Operation
Deletes a backup.
-
#delete_project_location_instance(name, force: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FileV1beta1::Operation
Deletes an instance.
-
#delete_project_location_instance_share(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FileV1beta1::Operation
Deletes a share.
-
#delete_project_location_instance_snapshot(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FileV1beta1::Operation
Deletes a snapshot.
-
#delete_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FileV1beta1::Empty
Deletes a long-running operation.
-
#get_project_location(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FileV1beta1::Location
Gets information about a location.
-
#get_project_location_backup(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FileV1beta1::Backup
Gets the details of a specific backup.
-
#get_project_location_instance(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FileV1beta1::Instance
Gets the details of a specific instance.
-
#get_project_location_instance_share(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FileV1beta1::Share
Gets the details of a specific share.
-
#get_project_location_instance_snapshot(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FileV1beta1::Snapshot
Gets the details of a specific snapshot.
-
#get_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FileV1beta1::Operation
Gets the latest state of a long-running operation.
-
#initialize ⇒ CloudFilestoreService
constructor
A new instance of CloudFilestoreService.
-
#list_project_location_backups(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FileV1beta1::ListBackupsResponse
Lists all backups in a project for either a specified location or for all locations.
-
#list_project_location_instance_shares(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FileV1beta1::ListSharesResponse
Lists all shares for a specified instance.
-
#list_project_location_instance_snapshots(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FileV1beta1::ListSnapshotsResponse
Lists all snapshots in a project for either a specified location or for all locations.
-
#list_project_location_instances(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FileV1beta1::ListInstancesResponse
Lists all instances in a project for either a specified location or for all locations.
-
#list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FileV1beta1::ListOperationsResponse
Lists operations that match the specified filter in the request.
-
#list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FileV1beta1::ListLocationsResponse
Lists information about the supported locations for this service.
-
#patch_project_location_backup(name, backup_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FileV1beta1::Operation
Updates the settings of a specific backup.
-
#patch_project_location_instance(name, instance_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FileV1beta1::Operation
Updates the settings of a specific instance.
-
#patch_project_location_instance_share(name, share_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FileV1beta1::Operation
Updates the settings of a specific share.
-
#patch_project_location_instance_snapshot(name, snapshot_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FileV1beta1::Operation
Updates the settings of a specific snapshot.
-
#pause_instance_replica(name, pause_replica_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FileV1beta1::Operation
Pause the standby instance (replica).
-
#promote_instance_replica(name, promote_replica_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FileV1beta1::Operation
Promote the standby instance (replica).
-
#restore_instance(name, restore_instance_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FileV1beta1::Operation
Restores an existing instance's file share from a backup.
-
#resume_instance_replica(name, resume_replica_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FileV1beta1::Operation
Resume the standby instance (replica).
-
#revert_instance(name, revert_instance_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FileV1beta1::Operation
Revert an existing instance's file system to a specified snapshot.
Constructor Details
#initialize ⇒ CloudFilestoreService
Returns a new instance of CloudFilestoreService.
47 48 49 50 51 52 |
# File 'lib/google/apis/file_v1beta1/service.rb', line 47 def initialize super(DEFAULT_ENDPOINT_TEMPLATE, '', client_name: 'google-apis-file_v1beta1', client_version: Google::Apis::FileV1beta1::GEM_VERSION) @batch_path = 'batch' end |
Instance Attribute Details
#key ⇒ String
Returns API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
40 41 42 |
# File 'lib/google/apis/file_v1beta1/service.rb', line 40 def key @key end |
#quota_user ⇒ String
Returns Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
45 46 47 |
# File 'lib/google/apis/file_v1beta1/service.rb', line 45 def quota_user @quota_user end |
Instance Method Details
#cancel_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FileV1beta1::Empty
Starts asynchronous cancellation on a long-running operation. The server makes
a best effort to cancel the operation, but success is not guaranteed. If the
server doesn't support this method, it returns google.rpc.Code.UNIMPLEMENTED.
Clients can use Operations.GetOperation or other methods to check whether the
cancellation succeeded or whether the operation completed despite cancellation.
On successful cancellation, the operation is not deleted; instead, it becomes
an operation with an Operation.error value with a google.rpc.Status.code of 1
, corresponding to Code.CANCELLED.
1102 1103 1104 1105 1106 1107 1108 1109 1110 1111 1112 |
# File 'lib/google/apis/file_v1beta1/service.rb', line 1102 def cancel_operation(name, cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta1/{+name}:cancel', ) command.request_representation = Google::Apis::FileV1beta1::CancelOperationRequest::Representation command.request_object = cancel_operation_request_object command.response_representation = Google::Apis::FileV1beta1::Empty::Representation command.response_class = Google::Apis::FileV1beta1::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_location_backup(parent, backup_object = nil, backup_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FileV1beta1::Operation
Creates a backup.
168 169 170 171 172 173 174 175 176 177 178 179 |
# File 'lib/google/apis/file_v1beta1/service.rb', line 168 def create_project_location_backup(parent, backup_object = nil, backup_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta1/{+parent}/backups', ) command.request_representation = Google::Apis::FileV1beta1::Backup::Representation command.request_object = backup_object command.response_representation = Google::Apis::FileV1beta1::Operation::Representation command.response_class = Google::Apis::FileV1beta1::Operation command.params['parent'] = parent unless parent.nil? command.query['backupId'] = backup_id unless backup_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_location_instance(parent, instance_object = nil, instance_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FileV1beta1::Operation
Creates an instance. When creating from a backup, the capacity of the new instance needs to be equal to or larger than the capacity of the backup (and also equal to or larger than the minimum capacity of the tier).
359 360 361 362 363 364 365 366 367 368 369 370 |
# File 'lib/google/apis/file_v1beta1/service.rb', line 359 def create_project_location_instance(parent, instance_object = nil, instance_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta1/{+parent}/instances', ) command.request_representation = Google::Apis::FileV1beta1::Instance::Representation command.request_object = instance_object command.response_representation = Google::Apis::FileV1beta1::Operation::Representation command.response_class = Google::Apis::FileV1beta1::Operation command.params['parent'] = parent unless parent.nil? command.query['instanceId'] = instance_id unless instance_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_location_instance_share(parent, share_object = nil, share_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FileV1beta1::Operation
Creates a share.
727 728 729 730 731 732 733 734 735 736 737 738 |
# File 'lib/google/apis/file_v1beta1/service.rb', line 727 def create_project_location_instance_share(parent, share_object = nil, share_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta1/{+parent}/shares', ) command.request_representation = Google::Apis::FileV1beta1::Share::Representation command.request_object = share_object command.response_representation = Google::Apis::FileV1beta1::Operation::Representation command.response_class = Google::Apis::FileV1beta1::Operation command.params['parent'] = parent unless parent.nil? command.query['shareId'] = share_id unless share_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_location_instance_snapshot(parent, snapshot_object = nil, snapshot_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FileV1beta1::Operation
Creates a snapshot.
911 912 913 914 915 916 917 918 919 920 921 922 |
# File 'lib/google/apis/file_v1beta1/service.rb', line 911 def create_project_location_instance_snapshot(parent, snapshot_object = nil, snapshot_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta1/{+parent}/snapshots', ) command.request_representation = Google::Apis::FileV1beta1::Snapshot::Representation command.request_object = snapshot_object command.response_representation = Google::Apis::FileV1beta1::Operation::Representation command.response_class = Google::Apis::FileV1beta1::Operation command.params['parent'] = parent unless parent.nil? command.query['snapshotId'] = snapshot_id unless snapshot_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_backup(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FileV1beta1::Operation
Deletes a backup.
202 203 204 205 206 207 208 209 210 |
# File 'lib/google/apis/file_v1beta1/service.rb', line 202 def delete_project_location_backup(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1beta1/{+name}', ) command.response_representation = Google::Apis::FileV1beta1::Operation::Representation command.response_class = Google::Apis::FileV1beta1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_instance(name, force: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FileV1beta1::Operation
Deletes an instance.
396 397 398 399 400 401 402 403 404 405 |
# File 'lib/google/apis/file_v1beta1/service.rb', line 396 def delete_project_location_instance(name, force: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1beta1/{+name}', ) command.response_representation = Google::Apis::FileV1beta1::Operation::Representation command.response_class = Google::Apis::FileV1beta1::Operation command.params['name'] = name unless name.nil? command.query['force'] = force unless force.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_instance_share(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FileV1beta1::Operation
Deletes a share.
761 762 763 764 765 766 767 768 769 |
# File 'lib/google/apis/file_v1beta1/service.rb', line 761 def delete_project_location_instance_share(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1beta1/{+name}', ) command.response_representation = Google::Apis::FileV1beta1::Operation::Representation command.response_class = Google::Apis::FileV1beta1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_instance_snapshot(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FileV1beta1::Operation
Deletes a snapshot.
945 946 947 948 949 950 951 952 953 |
# File 'lib/google/apis/file_v1beta1/service.rb', line 945 def delete_project_location_instance_snapshot(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1beta1/{+name}', ) command.response_representation = Google::Apis::FileV1beta1::Operation::Representation command.response_class = Google::Apis::FileV1beta1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FileV1beta1::Empty
Deletes a long-running operation. This method indicates that the client is no
longer interested in the operation result. It does not cancel the operation.
If the server doesn't support this method, it returns google.rpc.Code.
UNIMPLEMENTED.
1137 1138 1139 1140 1141 1142 1143 1144 1145 |
# File 'lib/google/apis/file_v1beta1/service.rb', line 1137 def delete_project_location_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1beta1/{+name}', ) command.response_representation = Google::Apis::FileV1beta1::Empty::Representation command.response_class = Google::Apis::FileV1beta1::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FileV1beta1::Location
Gets information about a location.
74 75 76 77 78 79 80 81 82 |
# File 'lib/google/apis/file_v1beta1/service.rb', line 74 def get_project_location(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/{+name}', ) command.response_representation = Google::Apis::FileV1beta1::Location::Representation command.response_class = Google::Apis::FileV1beta1::Location command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_backup(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FileV1beta1::Backup
Gets the details of a specific backup.
233 234 235 236 237 238 239 240 241 |
# File 'lib/google/apis/file_v1beta1/service.rb', line 233 def get_project_location_backup(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/{+name}', ) command.response_representation = Google::Apis::FileV1beta1::Backup::Representation command.response_class = Google::Apis::FileV1beta1::Backup command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_instance(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FileV1beta1::Instance
Gets the details of a specific instance.
428 429 430 431 432 433 434 435 436 |
# File 'lib/google/apis/file_v1beta1/service.rb', line 428 def get_project_location_instance(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/{+name}', ) command.response_representation = Google::Apis::FileV1beta1::Instance::Representation command.response_class = Google::Apis::FileV1beta1::Instance command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_instance_share(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FileV1beta1::Share
Gets the details of a specific share.
792 793 794 795 796 797 798 799 800 |
# File 'lib/google/apis/file_v1beta1/service.rb', line 792 def get_project_location_instance_share(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/{+name}', ) command.response_representation = Google::Apis::FileV1beta1::Share::Representation command.response_class = Google::Apis::FileV1beta1::Share command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_instance_snapshot(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FileV1beta1::Snapshot
Gets the details of a specific snapshot.
976 977 978 979 980 981 982 983 984 |
# File 'lib/google/apis/file_v1beta1/service.rb', line 976 def get_project_location_instance_snapshot(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/{+name}', ) command.response_representation = Google::Apis::FileV1beta1::Snapshot::Representation command.response_class = Google::Apis::FileV1beta1::Snapshot command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FileV1beta1::Operation
Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
1168 1169 1170 1171 1172 1173 1174 1175 1176 |
# File 'lib/google/apis/file_v1beta1/service.rb', line 1168 def get_project_location_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/{+name}', ) command.response_representation = Google::Apis::FileV1beta1::Operation::Representation command.response_class = Google::Apis::FileV1beta1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_backups(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FileV1beta1::ListBackupsResponse
Lists all backups in a project for either a specified location or for all locations.
277 278 279 280 281 282 283 284 285 286 287 288 289 |
# File 'lib/google/apis/file_v1beta1/service.rb', line 277 def list_project_location_backups(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/{+parent}/backups', ) command.response_representation = Google::Apis::FileV1beta1::ListBackupsResponse::Representation command.response_class = Google::Apis::FileV1beta1::ListBackupsResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['orderBy'] = order_by unless order_by.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_instance_shares(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FileV1beta1::ListSharesResponse
Lists all shares for a specified instance.
832 833 834 835 836 837 838 839 840 841 842 843 844 |
# File 'lib/google/apis/file_v1beta1/service.rb', line 832 def list_project_location_instance_shares(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/{+parent}/shares', ) command.response_representation = Google::Apis::FileV1beta1::ListSharesResponse::Representation command.response_class = Google::Apis::FileV1beta1::ListSharesResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['orderBy'] = order_by unless order_by.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_instance_snapshots(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FileV1beta1::ListSnapshotsResponse
Lists all snapshots in a project for either a specified location or for all locations.
1020 1021 1022 1023 1024 1025 1026 1027 1028 1029 1030 1031 1032 1033 |
# File 'lib/google/apis/file_v1beta1/service.rb', line 1020 def list_project_location_instance_snapshots(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/{+parent}/snapshots', ) command.response_representation = Google::Apis::FileV1beta1::ListSnapshotsResponse::Representation command.response_class = Google::Apis::FileV1beta1::ListSnapshotsResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['orderBy'] = order_by unless order_by.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['returnPartialSuccess'] = return_partial_success unless return_partial_success.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_instances(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FileV1beta1::ListInstancesResponse
Lists all instances in a project for either a specified location or for all locations.
471 472 473 474 475 476 477 478 479 480 481 482 483 |
# File 'lib/google/apis/file_v1beta1/service.rb', line 471 def list_project_location_instances(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/{+parent}/instances', ) command.response_representation = Google::Apis::FileV1beta1::ListInstancesResponse::Representation command.response_class = Google::Apis::FileV1beta1::ListInstancesResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['orderBy'] = order_by unless order_by.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FileV1beta1::ListOperationsResponse
Lists operations that match the specified filter in the request. If the server
doesn't support this method, it returns UNIMPLEMENTED.
1213 1214 1215 1216 1217 1218 1219 1220 1221 1222 1223 1224 1225 |
# File 'lib/google/apis/file_v1beta1/service.rb', line 1213 def list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/{+name}/operations', ) command.response_representation = Google::Apis::FileV1beta1::ListOperationsResponse::Representation command.response_class = Google::Apis::FileV1beta1::ListOperationsResponse command.params['name'] = name unless name.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['returnPartialSuccess'] = return_partial_success unless return_partial_success.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FileV1beta1::ListLocationsResponse
Lists information about the supported locations for this service. This method
lists locations based on the resource scope provided in the
ListLocationsRequest.name field: * Global locations: If name is empty,
the method lists the public locations available to all projects. * Project-
specific locations: If name follows the format projects/project`, the
method lists locations visible to that specific project. This includes public,
private, or other project-specific locations enabled for the project. For gRPC
and client library implementations, the resource name is passed as thename`
field. For direct service calls, the resource name is incorporated into the
request path based on the specific service implementation and version.
126 127 128 129 130 131 132 133 134 135 136 137 138 |
# File 'lib/google/apis/file_v1beta1/service.rb', line 126 def list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta1/{+name}/locations', ) command.response_representation = Google::Apis::FileV1beta1::ListLocationsResponse::Representation command.response_class = Google::Apis::FileV1beta1::ListLocationsResponse command.params['name'] = name unless name.nil? command.query['extraLocationTypes'] = extra_location_types unless extra_location_types.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_location_backup(name, backup_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FileV1beta1::Operation
Updates the settings of a specific backup.
316 317 318 319 320 321 322 323 324 325 326 327 |
# File 'lib/google/apis/file_v1beta1/service.rb', line 316 def patch_project_location_backup(name, backup_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1beta1/{+name}', ) command.request_representation = Google::Apis::FileV1beta1::Backup::Representation command.request_object = backup_object command.response_representation = Google::Apis::FileV1beta1::Operation::Representation command.response_class = Google::Apis::FileV1beta1::Operation command.params['name'] = name unless name.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_location_instance(name, instance_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FileV1beta1::Operation
Updates the settings of a specific instance.
513 514 515 516 517 518 519 520 521 522 523 524 |
# File 'lib/google/apis/file_v1beta1/service.rb', line 513 def patch_project_location_instance(name, instance_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1beta1/{+name}', ) command.request_representation = Google::Apis::FileV1beta1::Instance::Representation command.request_object = instance_object command.response_representation = Google::Apis::FileV1beta1::Operation::Representation command.response_class = Google::Apis::FileV1beta1::Operation command.params['name'] = name unless name.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_location_instance_share(name, share_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FileV1beta1::Operation
Updates the settings of a specific share.
872 873 874 875 876 877 878 879 880 881 882 883 |
# File 'lib/google/apis/file_v1beta1/service.rb', line 872 def patch_project_location_instance_share(name, share_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1beta1/{+name}', ) command.request_representation = Google::Apis::FileV1beta1::Share::Representation command.request_object = share_object command.response_representation = Google::Apis::FileV1beta1::Operation::Representation command.response_class = Google::Apis::FileV1beta1::Operation command.params['name'] = name unless name.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_location_instance_snapshot(name, snapshot_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FileV1beta1::Operation
Updates the settings of a specific snapshot.
1061 1062 1063 1064 1065 1066 1067 1068 1069 1070 1071 1072 |
# File 'lib/google/apis/file_v1beta1/service.rb', line 1061 def patch_project_location_instance_snapshot(name, snapshot_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1beta1/{+name}', ) command.request_representation = Google::Apis::FileV1beta1::Snapshot::Representation command.request_object = snapshot_object command.response_representation = Google::Apis::FileV1beta1::Operation::Representation command.response_class = Google::Apis::FileV1beta1::Operation command.params['name'] = name unless name.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#pause_instance_replica(name, pause_replica_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FileV1beta1::Operation
Pause the standby instance (replica). WARNING: This operation makes the standby instance's NFS filesystem writable. Any data written to the standby instance while paused will be lost when the replica is resumed or promoted.
550 551 552 553 554 555 556 557 558 559 560 |
# File 'lib/google/apis/file_v1beta1/service.rb', line 550 def pause_instance_replica(name, pause_replica_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta1/{+name}:pauseReplica', ) command.request_representation = Google::Apis::FileV1beta1::PauseReplicaRequest::Representation command.request_object = pause_replica_request_object command.response_representation = Google::Apis::FileV1beta1::Operation::Representation command.response_class = Google::Apis::FileV1beta1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#promote_instance_replica(name, promote_replica_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FileV1beta1::Operation
Promote the standby instance (replica).
584 585 586 587 588 589 590 591 592 593 594 |
# File 'lib/google/apis/file_v1beta1/service.rb', line 584 def promote_instance_replica(name, promote_replica_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta1/{+name}:promoteReplica', ) command.request_representation = Google::Apis::FileV1beta1::PromoteReplicaRequest::Representation command.request_object = promote_replica_request_object command.response_representation = Google::Apis::FileV1beta1::Operation::Representation command.response_class = Google::Apis::FileV1beta1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#restore_instance(name, restore_instance_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FileV1beta1::Operation
Restores an existing instance's file share from a backup. The capacity of the instance needs to be equal to or larger than the capacity of the backup (and also equal to or larger than the minimum capacity of the tier).
620 621 622 623 624 625 626 627 628 629 630 |
# File 'lib/google/apis/file_v1beta1/service.rb', line 620 def restore_instance(name, restore_instance_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta1/{+name}:restore', ) command.request_representation = Google::Apis::FileV1beta1::RestoreInstanceRequest::Representation command.request_object = restore_instance_request_object command.response_representation = Google::Apis::FileV1beta1::Operation::Representation command.response_class = Google::Apis::FileV1beta1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#resume_instance_replica(name, resume_replica_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FileV1beta1::Operation
Resume the standby instance (replica). WARNING: Any data written to the standby instance while paused will be lost when the replica is resumed.
655 656 657 658 659 660 661 662 663 664 665 |
# File 'lib/google/apis/file_v1beta1/service.rb', line 655 def resume_instance_replica(name, resume_replica_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta1/{+name}:resumeReplica', ) command.request_representation = Google::Apis::FileV1beta1::ResumeReplicaRequest::Representation command.request_object = resume_replica_request_object command.response_representation = Google::Apis::FileV1beta1::Operation::Representation command.response_class = Google::Apis::FileV1beta1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#revert_instance(name, revert_instance_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::FileV1beta1::Operation
Revert an existing instance's file system to a specified snapshot.
689 690 691 692 693 694 695 696 697 698 699 |
# File 'lib/google/apis/file_v1beta1/service.rb', line 689 def revert_instance(name, revert_instance_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta1/{+name}:revert', ) command.request_representation = Google::Apis::FileV1beta1::RevertInstanceRequest::Representation command.request_object = revert_instance_request_object command.response_representation = Google::Apis::FileV1beta1::Operation::Representation command.response_class = Google::Apis::FileV1beta1::Operation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |