Class: Google::Apis::FileV1beta1::GoogleCloudSaasacceleratorManagementProvidersV1MaintenanceSettings

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/file_v1beta1/classes.rb,
lib/google/apis/file_v1beta1/representations.rb,
lib/google/apis/file_v1beta1/representations.rb

Overview

Maintenance settings associated with instance. Allows service producers and end users to assign settings that controls maintenance on this instance.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSaasacceleratorManagementProvidersV1MaintenanceSettings

Returns a new instance of GoogleCloudSaasacceleratorManagementProvidersV1MaintenanceSettings.



703
704
705
# File 'lib/google/apis/file_v1beta1/classes.rb', line 703

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#excludeBoolean Also known as: exclude?

Optional. Exclude instance from maintenance. When true, rollout service will not attempt maintenance on the instance. Rollout service will include the instance in reported rollout progress as not attempted. Corresponds to the JSON property exclude

Returns:

  • (Boolean)


684
685
686
# File 'lib/google/apis/file_v1beta1/classes.rb', line 684

def exclude
  @exclude
end

#is_rollbackBoolean Also known as: is_rollback?

Optional. If the update call is triggered from rollback, set the value as true. Corresponds to the JSON property isRollback

Returns:

  • (Boolean)


690
691
692
# File 'lib/google/apis/file_v1beta1/classes.rb', line 690

def is_rollback
  @is_rollback
end

#maintenance_policiesHash<String,Google::Apis::FileV1beta1::MaintenancePolicy>

Optional. The MaintenancePolicies that have been attached to the instance. The key must be of the type name of the oneof policy name defined in MaintenancePolicy, and the embedded policy must define the same policy type. For details, please refer to go/mr-user-guide. Should not be set if maintenance_policy_names is set. If only the name is needed, then only populate MaintenancePolicy.name. Corresponds to the JSON property maintenancePolicies



701
702
703
# File 'lib/google/apis/file_v1beta1/classes.rb', line 701

def maintenance_policies
  @maintenance_policies
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



708
709
710
711
712
# File 'lib/google/apis/file_v1beta1/classes.rb', line 708

def update!(**args)
  @exclude = args[:exclude] if args.key?(:exclude)
  @is_rollback = args[:is_rollback] if args.key?(:is_rollback)
  @maintenance_policies = args[:maintenance_policies] if args.key?(:maintenance_policies)
end