Class: Google::Apis::FileV1beta1::ListInstancesResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/file_v1beta1/classes.rb,
lib/google/apis/file_v1beta1/representations.rb,
lib/google/apis/file_v1beta1/representations.rb

Overview

ListInstancesResponse is the result of ListInstancesRequest.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListInstancesResponse

Returns a new instance of ListInstancesResponse.



1242
1243
1244
# File 'lib/google/apis/file_v1beta1/classes.rb', line 1242

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#instancesArray<Google::Apis::FileV1beta1::Instance>

A list of instances in the project for the specified location. If the location value in the request is "-", the response contains a list of instances from all locations. If any location is unreachable, the response will only return instances in reachable locations and the "unreachable" field will be populated with a list of unreachable locations. Corresponds to the JSON property instances



1229
1230
1231
# File 'lib/google/apis/file_v1beta1/classes.rb', line 1229

def instances
  @instances
end

#next_page_tokenString

The token you can use to retrieve the next page of results. Not returned if there are no more results in the list. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


1235
1236
1237
# File 'lib/google/apis/file_v1beta1/classes.rb', line 1235

def next_page_token
  @next_page_token
end

#unreachableArray<String>

Unordered list. Locations that could not be reached. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


1240
1241
1242
# File 'lib/google/apis/file_v1beta1/classes.rb', line 1240

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1247
1248
1249
1250
1251
# File 'lib/google/apis/file_v1beta1/classes.rb', line 1247

def update!(**args)
  @instances = args[:instances] if args.key?(:instances)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end