Class: Google::Apis::FileV1beta1::ListOperationsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/file_v1beta1/classes.rb,
lib/google/apis/file_v1beta1/representations.rb,
lib/google/apis/file_v1beta1/representations.rb

Overview

The response message for Operations.ListOperations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListOperationsResponse

Returns a new instance of ListOperationsResponse.



1245
1246
1247
# File 'lib/google/apis/file_v1beta1/classes.rb', line 1245

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

The standard List next-page token. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


1230
1231
1232
# File 'lib/google/apis/file_v1beta1/classes.rb', line 1230

def next_page_token
  @next_page_token
end

#operationsArray<Google::Apis::FileV1beta1::Operation>

A list of operations that matches the specified filter in the request. Corresponds to the JSON property operations



1235
1236
1237
# File 'lib/google/apis/file_v1beta1/classes.rb', line 1235

def operations
  @operations
end

#unreachableArray<String>

Unordered list. Unreachable resources. Populated when the request sets ListOperationsRequest.return_partial_success and reads across collections. For example, when attempting to list all resources across all supported locations. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


1243
1244
1245
# File 'lib/google/apis/file_v1beta1/classes.rb', line 1243

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1250
1251
1252
1253
1254
# File 'lib/google/apis/file_v1beta1/classes.rb', line 1250

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @operations = args[:operations] if args.key?(:operations)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end