Class: Google::Apis::FileV1beta1::ListSnapshotsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/file_v1beta1/classes.rb,
lib/google/apis/file_v1beta1/representations.rb,
lib/google/apis/file_v1beta1/representations.rb

Overview

ListSnapshotsResponse is the result of ListSnapshotsRequest.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListSnapshotsResponse

Returns a new instance of ListSnapshotsResponse.



1365
1366
1367
# File 'lib/google/apis/file_v1beta1/classes.rb', line 1365

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

The token you can use to retrieve the next page of results. Not returned if there are no more results in the list. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


1353
1354
1355
# File 'lib/google/apis/file_v1beta1/classes.rb', line 1353

def next_page_token
  @next_page_token
end

#snapshotsArray<Google::Apis::FileV1beta1::Snapshot>

A list of snapshots in the project for the specified instance. Corresponds to the JSON property snapshots



1358
1359
1360
# File 'lib/google/apis/file_v1beta1/classes.rb', line 1358

def snapshots
  @snapshots
end

#unreachableArray<String>

Unordered list. Locations that could not be reached. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


1363
1364
1365
# File 'lib/google/apis/file_v1beta1/classes.rb', line 1363

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1370
1371
1372
1373
1374
# File 'lib/google/apis/file_v1beta1/classes.rb', line 1370

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @snapshots = args[:snapshots] if args.key?(:snapshots)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end