Class: Google::Apis::FileV1beta1::ManagedActiveDirectoryConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/file_v1beta1/classes.rb,
lib/google/apis/file_v1beta1/representations.rb,
lib/google/apis/file_v1beta1/representations.rb

Overview

ManagedActiveDirectoryConfig contains all the parameters for connecting to Managed Service for Microsoft Active Directory (Managed Microsoft AD).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ManagedActiveDirectoryConfig

Returns a new instance of ManagedActiveDirectoryConfig.



1473
1474
1475
# File 'lib/google/apis/file_v1beta1/classes.rb', line 1473

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#computerString

Required. The computer name is used as a prefix in the command to mount the remote target. For example: if the computer is my-computer, the mount command will look like: $mount -o vers=4.1,sec=krb5 my-computer.filestore.:. Corresponds to the JSON property computer

Returns:

  • (String)


1465
1466
1467
# File 'lib/google/apis/file_v1beta1/classes.rb', line 1465

def computer
  @computer
end

#domainString

Required. The domain resource name, in the format projects/project_id/ locations/global/domains/domain`. Corresponds to the JSON propertydomain`

Returns:

  • (String)


1471
1472
1473
# File 'lib/google/apis/file_v1beta1/classes.rb', line 1471

def domain
  @domain
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1478
1479
1480
1481
# File 'lib/google/apis/file_v1beta1/classes.rb', line 1478

def update!(**args)
  @computer = args[:computer] if args.key?(:computer)
  @domain = args[:domain] if args.key?(:domain)
end