Class: Google::Apis::FileV1beta1::NfsExportOptions

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/file_v1beta1/classes.rb,
lib/google/apis/file_v1beta1/representations.rb,
lib/google/apis/file_v1beta1/representations.rb

Overview

NFS export options specifications.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NfsExportOptions

Returns a new instance of NfsExportOptions.



1604
1605
1606
# File 'lib/google/apis/file_v1beta1/classes.rb', line 1604

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#access_modeString

Either READ_ONLY, for allowing only read requests on the exported directory, or READ_WRITE, for allowing both read and write requests. The default is READ_WRITE. Corresponds to the JSON property accessMode

Returns:

  • (String)


1560
1561
1562
# File 'lib/google/apis/file_v1beta1/classes.rb', line 1560

def access_mode
  @access_mode
end

#anon_gidFixnum

An integer representing the anonymous group id with a default value of 65534. Anon_gid may only be set with squash_mode of ROOT_SQUASH. An error will be returned if this field is specified for other squash_mode settings. Corresponds to the JSON property anonGid

Returns:

  • (Fixnum)


1567
1568
1569
# File 'lib/google/apis/file_v1beta1/classes.rb', line 1567

def anon_gid
  @anon_gid
end

#anon_uidFixnum

An integer representing the anonymous user id with a default value of 65534. Anon_uid may only be set with squash_mode of ROOT_SQUASH. An error will be returned if this field is specified for other squash_mode settings. Corresponds to the JSON property anonUid

Returns:

  • (Fixnum)


1574
1575
1576
# File 'lib/google/apis/file_v1beta1/classes.rb', line 1574

def anon_uid
  @anon_uid
end

#ip_rangesArray<String>

List of either an IPv4 addresses in the format octet1`.`octet2`.`octet3`.` octet4 or CIDR ranges in the format octet1`.`octet2`.`octet3`.`octet4`/` mask size which may mount the file share. Overlapping IP ranges are not allowed, both within and across NfsExportOptions. An error will be returned. The limit is 64 IP ranges/addresses for each FileShareConfig among all NfsExportOptions. Corresponds to the JSON property ipRanges

Returns:

  • (Array<String>)


1584
1585
1586
# File 'lib/google/apis/file_v1beta1/classes.rb', line 1584

def ip_ranges
  @ip_ranges
end

#networkString

Optional. The source VPC network for ip_ranges. Required for instances using Private Service Connect, optional otherwise. If provided, must be the same network specified in the NetworkConfig.network field. Corresponds to the JSON property network

Returns:

  • (String)


1591
1592
1593
# File 'lib/google/apis/file_v1beta1/classes.rb', line 1591

def network
  @network
end

#security_flavorsArray<String>

The security flavors allowed for mount operations. The default is AUTH_SYS. Corresponds to the JSON property securityFlavors

Returns:

  • (Array<String>)


1596
1597
1598
# File 'lib/google/apis/file_v1beta1/classes.rb', line 1596

def security_flavors
  @security_flavors
end

#squash_modeString

Either NO_ROOT_SQUASH, for allowing root access on the exported directory, or ROOT_SQUASH, for not allowing root access. The default is NO_ROOT_SQUASH. Corresponds to the JSON property squashMode

Returns:

  • (String)


1602
1603
1604
# File 'lib/google/apis/file_v1beta1/classes.rb', line 1602

def squash_mode
  @squash_mode
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1609
1610
1611
1612
1613
1614
1615
1616
1617
# File 'lib/google/apis/file_v1beta1/classes.rb', line 1609

def update!(**args)
  @access_mode = args[:access_mode] if args.key?(:access_mode)
  @anon_gid = args[:anon_gid] if args.key?(:anon_gid)
  @anon_uid = args[:anon_uid] if args.key?(:anon_uid)
  @ip_ranges = args[:ip_ranges] if args.key?(:ip_ranges)
  @network = args[:network] if args.key?(:network)
  @security_flavors = args[:security_flavors] if args.key?(:security_flavors)
  @squash_mode = args[:squash_mode] if args.key?(:squash_mode)
end