Class: Google::Apis::FileV1beta1::PscConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/file_v1beta1/classes.rb,
lib/google/apis/file_v1beta1/representations.rb,
lib/google/apis/file_v1beta1/representations.rb

Overview

Private Service Connect configuration.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PscConfig

Returns a new instance of PscConfig.



1861
1862
1863
# File 'lib/google/apis/file_v1beta1/classes.rb', line 1861

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#endpoint_projectString

Consumer service project in which the Private Service Connect endpoint would be set up. This is optional, and only relevant in case the network is a shared VPC. If this is not specified, the endpoint would be setup in the VPC host project. Corresponds to the JSON property endpointProject

Returns:

  • (String)


1859
1860
1861
# File 'lib/google/apis/file_v1beta1/classes.rb', line 1859

def endpoint_project
  @endpoint_project
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1866
1867
1868
# File 'lib/google/apis/file_v1beta1/classes.rb', line 1866

def update!(**args)
  @endpoint_project = args[:endpoint_project] if args.key?(:endpoint_project)
end