Class: Google::Apis::FileV1beta1::Share
- Inherits:
-
Object
- Object
- Google::Apis::FileV1beta1::Share
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/file_v1beta1/classes.rb,
lib/google/apis/file_v1beta1/representations.rb,
lib/google/apis/file_v1beta1/representations.rb
Overview
A Filestore share.
Instance Attribute Summary collapse
-
#backup ⇒ String
Immutable.
-
#capacity_gb ⇒ Fixnum
File share capacity in gigabytes (GB).
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
A description of the share with 2048 characters or less.
-
#labels ⇒ Hash<String,String>
Resource labels to represent user provided metadata.
-
#mount_name ⇒ String
The mount name of the share.
-
#name ⇒ String
Output only.
-
#nfs_export_options ⇒ Array<Google::Apis::FileV1beta1::NfsExportOptions>
Nfs Export Options.
-
#state ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Share
constructor
A new instance of Share.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Share
Returns a new instance of Share.
2219 2220 2221 |
# File 'lib/google/apis/file_v1beta1/classes.rb', line 2219 def initialize(**args) update!(**args) end |
Instance Attribute Details
#backup ⇒ String
Immutable. Full name of the Cloud Filestore Backup resource that this Share is
restored from, in the format of projects/project_id/locations/location_id/
backups/backup_id. Empty, if the Share is created from scratch and not
restored from a backup.
Corresponds to the JSON property backup
2173 2174 2175 |
# File 'lib/google/apis/file_v1beta1/classes.rb', line 2173 def backup @backup end |
#capacity_gb ⇒ Fixnum
File share capacity in gigabytes (GB). Filestore defines 1 GB as 1024^3 bytes.
Must be greater than 0.
Corresponds to the JSON property capacityGb
2179 2180 2181 |
# File 'lib/google/apis/file_v1beta1/classes.rb', line 2179 def capacity_gb @capacity_gb end |
#create_time ⇒ String
Output only. The time when the share was created.
Corresponds to the JSON property createTime
2184 2185 2186 |
# File 'lib/google/apis/file_v1beta1/classes.rb', line 2184 def create_time @create_time end |
#description ⇒ String
A description of the share with 2048 characters or less. Requests with longer
descriptions will be rejected.
Corresponds to the JSON property description
2190 2191 2192 |
# File 'lib/google/apis/file_v1beta1/classes.rb', line 2190 def description @description end |
#labels ⇒ Hash<String,String>
Resource labels to represent user provided metadata.
Corresponds to the JSON property labels
2195 2196 2197 |
# File 'lib/google/apis/file_v1beta1/classes.rb', line 2195 def labels @labels end |
#mount_name ⇒ String
The mount name of the share. Must be 63 characters or less and consist of
uppercase or lowercase letters, numbers, and underscores.
Corresponds to the JSON property mountName
2201 2202 2203 |
# File 'lib/google/apis/file_v1beta1/classes.rb', line 2201 def mount_name @mount_name end |
#name ⇒ String
Output only. The resource name of the share, in the format projects/
project_id/locations/location_id/instances/instance_id/shares/share_id`.
Corresponds to the JSON propertyname`
2207 2208 2209 |
# File 'lib/google/apis/file_v1beta1/classes.rb', line 2207 def name @name end |
#nfs_export_options ⇒ Array<Google::Apis::FileV1beta1::NfsExportOptions>
Nfs Export Options. There is a limit of 10 export options per file share.
Corresponds to the JSON property nfsExportOptions
2212 2213 2214 |
# File 'lib/google/apis/file_v1beta1/classes.rb', line 2212 def @nfs_export_options end |
#state ⇒ String
Output only. The share state.
Corresponds to the JSON property state
2217 2218 2219 |
# File 'lib/google/apis/file_v1beta1/classes.rb', line 2217 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2224 2225 2226 2227 2228 2229 2230 2231 2232 2233 2234 |
# File 'lib/google/apis/file_v1beta1/classes.rb', line 2224 def update!(**args) @backup = args[:backup] if args.key?(:backup) @capacity_gb = args[:capacity_gb] if args.key?(:capacity_gb) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @labels = args[:labels] if args.key?(:labels) @mount_name = args[:mount_name] if args.key?(:mount_name) @name = args[:name] if args.key?(:name) @nfs_export_options = args[:nfs_export_options] if args.key?(:nfs_export_options) @state = args[:state] if args.key?(:state) end |