Class: Google::Apis::FileV1beta1::Snapshot
- Inherits:
-
Object
- Object
- Google::Apis::FileV1beta1::Snapshot
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/file_v1beta1/classes.rb,
lib/google/apis/file_v1beta1/representations.rb,
lib/google/apis/file_v1beta1/representations.rb
Overview
A Filestore snapshot.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
A description of the snapshot with 2048 characters or less.
-
#filesystem_used_bytes ⇒ Fixnum
Output only.
-
#labels ⇒ Hash<String,String>
Resource labels to represent user provided metadata.
-
#name ⇒ String
Output only.
-
#state ⇒ String
Output only.
-
#tags ⇒ Hash<String,String>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Snapshot
constructor
A new instance of Snapshot.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Snapshot
Returns a new instance of Snapshot.
2170 2171 2172 |
# File 'lib/google/apis/file_v1beta1/classes.rb', line 2170 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The time when the snapshot was created.
Corresponds to the JSON property createTime
2128 2129 2130 |
# File 'lib/google/apis/file_v1beta1/classes.rb', line 2128 def create_time @create_time end |
#description ⇒ String
A description of the snapshot with 2048 characters or less. Requests with
longer descriptions will be rejected.
Corresponds to the JSON property description
2134 2135 2136 |
# File 'lib/google/apis/file_v1beta1/classes.rb', line 2134 def description @description end |
#filesystem_used_bytes ⇒ Fixnum
Output only. The amount of bytes needed to allocate a full copy of the
snapshot content
Corresponds to the JSON property filesystemUsedBytes
2140 2141 2142 |
# File 'lib/google/apis/file_v1beta1/classes.rb', line 2140 def filesystem_used_bytes @filesystem_used_bytes end |
#labels ⇒ Hash<String,String>
Resource labels to represent user provided metadata.
Corresponds to the JSON property labels
2145 2146 2147 |
# File 'lib/google/apis/file_v1beta1/classes.rb', line 2145 def labels @labels end |
#name ⇒ String
Output only. The resource name of the snapshot, in the format projects/
project_id/locations/location_id/instances/instance_id/snapshots/
snapshot_id`.
Corresponds to the JSON propertyname`
2152 2153 2154 |
# File 'lib/google/apis/file_v1beta1/classes.rb', line 2152 def name @name end |
#state ⇒ String
Output only. The snapshot state.
Corresponds to the JSON property state
2157 2158 2159 |
# File 'lib/google/apis/file_v1beta1/classes.rb', line 2157 def state @state end |
#tags ⇒ Hash<String,String>
Optional. Input only. Immutable. Tag key-value pairs bound to this resource.
Each key must be a namespaced name and each value a short name. Example: "
123456789012/environment" : "production", "123456789013/costCenter" : "
marketing" See the documentation for more information: - Namespaced name:
https://cloud.google.com/resource-manager/docs/tags/tags-creating-and-managing#
retrieving_tag_key - Short name: https://cloud.google.com/resource-manager/
docs/tags/tags-creating-and-managing#retrieving_tag_value
Corresponds to the JSON property tags
2168 2169 2170 |
# File 'lib/google/apis/file_v1beta1/classes.rb', line 2168 def @tags end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2175 2176 2177 2178 2179 2180 2181 2182 2183 |
# File 'lib/google/apis/file_v1beta1/classes.rb', line 2175 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @filesystem_used_bytes = args[:filesystem_used_bytes] if args.key?(:filesystem_used_bytes) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @state = args[:state] if args.key?(:state) @tags = args[:tags] if args.key?(:tags) end |