Class: Google::Apis::FileV1beta1::GoogleCloudSaasacceleratorManagementProvidersV1SloEligibility
- Inherits:
-
Object
- Object
- Google::Apis::FileV1beta1::GoogleCloudSaasacceleratorManagementProvidersV1SloEligibility
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/file_v1beta1/classes.rb,
lib/google/apis/file_v1beta1/representations.rb,
lib/google/apis/file_v1beta1/representations.rb
Overview
SloEligibility is a tuple containing eligibility value: true if an instance is eligible for SLO calculation or false if it should be excluded from all SLO- related calculations along with a user-defined reason.
Instance Attribute Summary collapse
-
#eligible ⇒ Boolean
(also: #eligible?)
Whether an instance is eligible or ineligible.
-
#reason ⇒ String
User-defined reason for the current value of instance eligibility.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudSaasacceleratorManagementProvidersV1SloEligibility
constructor
A new instance of GoogleCloudSaasacceleratorManagementProvidersV1SloEligibility.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudSaasacceleratorManagementProvidersV1SloEligibility
Returns a new instance of GoogleCloudSaasacceleratorManagementProvidersV1SloEligibility.
839 840 841 |
# File 'lib/google/apis/file_v1beta1/classes.rb', line 839 def initialize(**args) update!(**args) end |
Instance Attribute Details
#eligible ⇒ Boolean Also known as: eligible?
Whether an instance is eligible or ineligible.
Corresponds to the JSON property eligible
830 831 832 |
# File 'lib/google/apis/file_v1beta1/classes.rb', line 830 def eligible @eligible end |
#reason ⇒ String
User-defined reason for the current value of instance eligibility. Usually,
this can be directly mapped to the internal state. An empty reason is allowed.
Corresponds to the JSON property reason
837 838 839 |
# File 'lib/google/apis/file_v1beta1/classes.rb', line 837 def reason @reason end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
844 845 846 847 |
# File 'lib/google/apis/file_v1beta1/classes.rb', line 844 def update!(**args) @eligible = args[:eligible] if args.key?(:eligible) @reason = args[:reason] if args.key?(:reason) end |