Class: Google::Apis::FileV1beta1::GoogleCloudSaasacceleratorManagementProvidersV1SloEligibility

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/file_v1beta1/classes.rb,
lib/google/apis/file_v1beta1/representations.rb,
lib/google/apis/file_v1beta1/representations.rb

Overview

SloEligibility is a tuple containing eligibility value: true if an instance is eligible for SLO calculation or false if it should be excluded from all SLO- related calculations along with a user-defined reason.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudSaasacceleratorManagementProvidersV1SloEligibility

Returns a new instance of GoogleCloudSaasacceleratorManagementProvidersV1SloEligibility.



788
789
790
# File 'lib/google/apis/file_v1beta1/classes.rb', line 788

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#eligibleBoolean Also known as: eligible?

Whether an instance is eligible or ineligible. Corresponds to the JSON property eligible

Returns:

  • (Boolean)


779
780
781
# File 'lib/google/apis/file_v1beta1/classes.rb', line 779

def eligible
  @eligible
end

#reasonString

User-defined reason for the current value of instance eligibility. Usually, this can be directly mapped to the internal state. An empty reason is allowed. Corresponds to the JSON property reason

Returns:

  • (String)


786
787
788
# File 'lib/google/apis/file_v1beta1/classes.rb', line 786

def reason
  @reason
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



793
794
795
796
# File 'lib/google/apis/file_v1beta1/classes.rb', line 793

def update!(**args)
  @eligible = args[:eligible] if args.key?(:eligible)
  @reason = args[:reason] if args.key?(:reason)
end