Class: Google::Apis::FileV1beta1::ListBackupsResponse
- Inherits:
-
Object
- Object
- Google::Apis::FileV1beta1::ListBackupsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/file_v1beta1/classes.rb,
lib/google/apis/file_v1beta1/representations.rb,
lib/google/apis/file_v1beta1/representations.rb
Overview
ListBackupsResponse is the result of ListBackupsRequest.
Instance Attribute Summary collapse
-
#backups ⇒ Array<Google::Apis::FileV1beta1::Backup>
A list of backups in the project for the specified location.
-
#next_page_token ⇒ String
The token you can use to retrieve the next page of results.
-
#unreachable ⇒ Array<String>
Unordered list.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListBackupsResponse
constructor
A new instance of ListBackupsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListBackupsResponse
Returns a new instance of ListBackupsResponse.
1149 1150 1151 |
# File 'lib/google/apis/file_v1beta1/classes.rb', line 1149 def initialize(**args) update!(**args) end |
Instance Attribute Details
#backups ⇒ Array<Google::Apis::FileV1beta1::Backup>
A list of backups in the project for the specified location. If the `location
value in the request is "-", the response contains a list of backups from
all locations. If any location is unreachable, the response will only return
backups in reachable locations and the "unreachable" field will be populated
with a list of unreachable locations.
Corresponds to the JSON propertybackups`
1136 1137 1138 |
# File 'lib/google/apis/file_v1beta1/classes.rb', line 1136 def backups @backups end |
#next_page_token ⇒ String
The token you can use to retrieve the next page of results. Not returned if
there are no more results in the list.
Corresponds to the JSON property nextPageToken
1142 1143 1144 |
# File 'lib/google/apis/file_v1beta1/classes.rb', line 1142 def next_page_token @next_page_token end |
#unreachable ⇒ Array<String>
Unordered list. Locations that could not be reached.
Corresponds to the JSON property unreachable
1147 1148 1149 |
# File 'lib/google/apis/file_v1beta1/classes.rb', line 1147 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1154 1155 1156 1157 1158 |
# File 'lib/google/apis/file_v1beta1/classes.rb', line 1154 def update!(**args) @backups = args[:backups] if args.key?(:backups) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @unreachable = args[:unreachable] if args.key?(:unreachable) end |