Class: Google::Apis::FileV1beta1::ListInstancesResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/file_v1beta1/classes.rb,
lib/google/apis/file_v1beta1/representations.rb,
lib/google/apis/file_v1beta1/representations.rb

Overview

ListInstancesResponse is the result of ListInstancesRequest.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListInstancesResponse

Returns a new instance of ListInstancesResponse.



1185
1186
1187
# File 'lib/google/apis/file_v1beta1/classes.rb', line 1185

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#instancesArray<Google::Apis::FileV1beta1::Instance>

A list of instances in the project for the specified location. If the location value in the request is "-", the response contains a list of instances from all locations. If any location is unreachable, the response will only return instances in reachable locations and the "unreachable" field will be populated with a list of unreachable locations. Corresponds to the JSON property instances



1172
1173
1174
# File 'lib/google/apis/file_v1beta1/classes.rb', line 1172

def instances
  @instances
end

#next_page_tokenString

The token you can use to retrieve the next page of results. Not returned if there are no more results in the list. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


1178
1179
1180
# File 'lib/google/apis/file_v1beta1/classes.rb', line 1178

def next_page_token
  @next_page_token
end

#unreachableArray<String>

Unordered list. Locations that could not be reached. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


1183
1184
1185
# File 'lib/google/apis/file_v1beta1/classes.rb', line 1183

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1190
1191
1192
1193
1194
# File 'lib/google/apis/file_v1beta1/classes.rb', line 1190

def update!(**args)
  @instances = args[:instances] if args.key?(:instances)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end