Class: Google::Apis::FileV1beta1::ListSharesResponse
- Inherits:
-
Object
- Object
- Google::Apis::FileV1beta1::ListSharesResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/file_v1beta1/classes.rb,
lib/google/apis/file_v1beta1/representations.rb,
lib/google/apis/file_v1beta1/representations.rb
Overview
ListSharesResponse is the result of ListSharesRequest.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
The token you can use to retrieve the next page of results.
-
#shares ⇒ Array<Google::Apis::FileV1beta1::Share>
A list of shares in the project for the specified instance.
-
#unreachable ⇒ Array<String>
Unordered list.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListSharesResponse
constructor
A new instance of ListSharesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListSharesResponse
Returns a new instance of ListSharesResponse.
1333 1334 1335 |
# File 'lib/google/apis/file_v1beta1/classes.rb', line 1333 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
The token you can use to retrieve the next page of results. Not returned if
there are no more results in the list.
Corresponds to the JSON property nextPageToken
1321 1322 1323 |
# File 'lib/google/apis/file_v1beta1/classes.rb', line 1321 def next_page_token @next_page_token end |
#shares ⇒ Array<Google::Apis::FileV1beta1::Share>
A list of shares in the project for the specified instance.
Corresponds to the JSON property shares
1326 1327 1328 |
# File 'lib/google/apis/file_v1beta1/classes.rb', line 1326 def shares @shares end |
#unreachable ⇒ Array<String>
Unordered list. Locations that could not be reached.
Corresponds to the JSON property unreachable
1331 1332 1333 |
# File 'lib/google/apis/file_v1beta1/classes.rb', line 1331 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1338 1339 1340 1341 1342 |
# File 'lib/google/apis/file_v1beta1/classes.rb', line 1338 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @shares = args[:shares] if args.key?(:shares) @unreachable = args[:unreachable] if args.key?(:unreachable) end |