Class: Google::Apis::FileV1beta1::ListSharesResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/file_v1beta1/classes.rb,
lib/google/apis/file_v1beta1/representations.rb,
lib/google/apis/file_v1beta1/representations.rb

Overview

ListSharesResponse is the result of ListSharesRequest.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListSharesResponse

Returns a new instance of ListSharesResponse.



1327
1328
1329
# File 'lib/google/apis/file_v1beta1/classes.rb', line 1327

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

The token you can use to retrieve the next page of results. Not returned if there are no more results in the list. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


1315
1316
1317
# File 'lib/google/apis/file_v1beta1/classes.rb', line 1315

def next_page_token
  @next_page_token
end

#sharesArray<Google::Apis::FileV1beta1::Share>

A list of shares in the project for the specified instance. Corresponds to the JSON property shares



1320
1321
1322
# File 'lib/google/apis/file_v1beta1/classes.rb', line 1320

def shares
  @shares
end

#unreachableArray<String>

Unordered list. Locations that could not be reached. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


1325
1326
1327
# File 'lib/google/apis/file_v1beta1/classes.rb', line 1325

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1332
1333
1334
1335
1336
# File 'lib/google/apis/file_v1beta1/classes.rb', line 1332

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @shares = args[:shares] if args.key?(:shares)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end