Class: Google::Apis::FileV1beta1::ListSnapshotsResponse
- Inherits:
-
Object
- Object
- Google::Apis::FileV1beta1::ListSnapshotsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/file_v1beta1/classes.rb,
lib/google/apis/file_v1beta1/representations.rb,
lib/google/apis/file_v1beta1/representations.rb
Overview
ListSnapshotsResponse is the result of ListSnapshotsRequest.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
The token you can use to retrieve the next page of results.
-
#snapshots ⇒ Array<Google::Apis::FileV1beta1::Snapshot>
A list of snapshots in the project for the specified instance.
-
#unreachable ⇒ Array<String>
Unordered list.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListSnapshotsResponse
constructor
A new instance of ListSnapshotsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListSnapshotsResponse
Returns a new instance of ListSnapshotsResponse.
1359 1360 1361 |
# File 'lib/google/apis/file_v1beta1/classes.rb', line 1359 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
The token you can use to retrieve the next page of results. Not returned if
there are no more results in the list.
Corresponds to the JSON property nextPageToken
1347 1348 1349 |
# File 'lib/google/apis/file_v1beta1/classes.rb', line 1347 def next_page_token @next_page_token end |
#snapshots ⇒ Array<Google::Apis::FileV1beta1::Snapshot>
A list of snapshots in the project for the specified instance.
Corresponds to the JSON property snapshots
1352 1353 1354 |
# File 'lib/google/apis/file_v1beta1/classes.rb', line 1352 def snapshots @snapshots end |
#unreachable ⇒ Array<String>
Unordered list. Locations that could not be reached.
Corresponds to the JSON property unreachable
1357 1358 1359 |
# File 'lib/google/apis/file_v1beta1/classes.rb', line 1357 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1364 1365 1366 1367 1368 |
# File 'lib/google/apis/file_v1beta1/classes.rb', line 1364 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @snapshots = args[:snapshots] if args.key?(:snapshots) @unreachable = args[:unreachable] if args.key?(:unreachable) end |