Class: Google::Apis::FileV1beta1::ListSnapshotsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/file_v1beta1/classes.rb,
lib/google/apis/file_v1beta1/representations.rb,
lib/google/apis/file_v1beta1/representations.rb

Overview

ListSnapshotsResponse is the result of ListSnapshotsRequest.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListSnapshotsResponse

Returns a new instance of ListSnapshotsResponse.



1308
1309
1310
# File 'lib/google/apis/file_v1beta1/classes.rb', line 1308

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

The token you can use to retrieve the next page of results. Not returned if there are no more results in the list. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


1296
1297
1298
# File 'lib/google/apis/file_v1beta1/classes.rb', line 1296

def next_page_token
  @next_page_token
end

#snapshotsArray<Google::Apis::FileV1beta1::Snapshot>

A list of snapshots in the project for the specified instance. Corresponds to the JSON property snapshots



1301
1302
1303
# File 'lib/google/apis/file_v1beta1/classes.rb', line 1301

def snapshots
  @snapshots
end

#unreachableArray<String>

Unordered list. Locations that could not be reached. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


1306
1307
1308
# File 'lib/google/apis/file_v1beta1/classes.rb', line 1306

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1313
1314
1315
1316
1317
# File 'lib/google/apis/file_v1beta1/classes.rb', line 1313

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @snapshots = args[:snapshots] if args.key?(:snapshots)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end