Class: Google::Apis::FileV1beta1::NetworkConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/file_v1beta1/classes.rb,
lib/google/apis/file_v1beta1/representations.rb,
lib/google/apis/file_v1beta1/representations.rb

Overview

Network configuration for the instance.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkConfig

Returns a new instance of NetworkConfig.



1536
1537
1538
# File 'lib/google/apis/file_v1beta1/classes.rb', line 1536

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#connect_modeString

The network connect mode of the Filestore instance. If not provided, the connect mode defaults to DIRECT_PEERING. Corresponds to the JSON property connectMode

Returns:

  • (String)


1492
1493
1494
# File 'lib/google/apis/file_v1beta1/classes.rb', line 1492

def connect_mode
  @connect_mode
end

#ip_addressesArray<String>

Output only. IPv4 addresses in the format octet1`.`octet2`.`octet3`.`octet4 or IPv6 addresses in the format block1`:`block2`:`block3`:`block4`:`block5`: `block6`:`block7`:`block8. Corresponds to the JSON property ipAddresses

Returns:

  • (Array<String>)


1499
1500
1501
# File 'lib/google/apis/file_v1beta1/classes.rb', line 1499

def ip_addresses
  @ip_addresses
end

#modesArray<String>

Internet protocol versions for which the instance has IP addresses assigned. For this version, only MODE_IPV4 is supported. Corresponds to the JSON property modes

Returns:

  • (Array<String>)


1505
1506
1507
# File 'lib/google/apis/file_v1beta1/classes.rb', line 1505

def modes
  @modes
end

#networkString

The name of the Google Compute Engine VPC network to which the instance is connected. Corresponds to the JSON property network

Returns:

  • (String)


1511
1512
1513
# File 'lib/google/apis/file_v1beta1/classes.rb', line 1511

def network
  @network
end

#psc_configGoogle::Apis::FileV1beta1::PscConfig

Private Service Connect configuration. Corresponds to the JSON property pscConfig



1516
1517
1518
# File 'lib/google/apis/file_v1beta1/classes.rb', line 1516

def psc_config
  @psc_config
end

#reserved_ip_rangeString

Optional, reserved_ip_range can have one of the following two types of values.

  • CIDR range value when using DIRECT_PEERING connect mode. * Allocated IP address range when using PRIVATE_SERVICE_ACCESS connect mode. When the name of an allocated IP address range is specified, it must be one of the ranges associated with the private service access connection. When specified as a direct CIDR value, it must be a /29 CIDR block for Basic tier, a /24 CIDR block for High Scale tier, or a /26 CIDR block for Enterprise tier in one of the internal IP address ranges that identifies the range of IP addresses reserved for this instance. For example, 10.0.0.0/29, 192.168.0.0/24, or 192.168.0.0/26, respectively. The range you specify can't overlap with either existing subnets or assigned IP address ranges for other Filestore instances in the selected VPC network. Corresponds to the JSON property reservedIpRange

Returns:

  • (String)


1534
1535
1536
# File 'lib/google/apis/file_v1beta1/classes.rb', line 1534

def reserved_ip_range
  @reserved_ip_range
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1541
1542
1543
1544
1545
1546
1547
1548
# File 'lib/google/apis/file_v1beta1/classes.rb', line 1541

def update!(**args)
  @connect_mode = args[:connect_mode] if args.key?(:connect_mode)
  @ip_addresses = args[:ip_addresses] if args.key?(:ip_addresses)
  @modes = args[:modes] if args.key?(:modes)
  @network = args[:network] if args.key?(:network)
  @psc_config = args[:psc_config] if args.key?(:psc_config)
  @reserved_ip_range = args[:reserved_ip_range] if args.key?(:reserved_ip_range)
end