Class: Google::Apis::FileV1beta1::PerformanceConfig
- Inherits:
-
Object
- Object
- Google::Apis::FileV1beta1::PerformanceConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/file_v1beta1/classes.rb,
lib/google/apis/file_v1beta1/representations.rb,
lib/google/apis/file_v1beta1/representations.rb
Overview
Used for setting the performance configuration. If the user doesn't specify PerformanceConfig, automatically provision the default performance settings as described in https://cloud.google.com/filestore/docs/performance. Larger instances will be linearly set to more IOPS. If the instance's capacity is increased or decreased, its performance will be automatically adjusted upwards or downwards accordingly (respectively).
Instance Attribute Summary collapse
-
#fixed_iops ⇒ Google::Apis::FileV1beta1::FixedIops
Fixed IOPS (input/output operations per second) parameters.
-
#iops_per_tb ⇒ Google::Apis::FileV1beta1::IopsPerTb
IOPS per TB.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PerformanceConfig
constructor
A new instance of PerformanceConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PerformanceConfig
Returns a new instance of PerformanceConfig.
1773 1774 1775 |
# File 'lib/google/apis/file_v1beta1/classes.rb', line 1773 def initialize(**args) update!(**args) end |
Instance Attribute Details
#fixed_iops ⇒ Google::Apis::FileV1beta1::FixedIops
Fixed IOPS (input/output operations per second) parameters.
Corresponds to the JSON property fixedIops
1766 1767 1768 |
# File 'lib/google/apis/file_v1beta1/classes.rb', line 1766 def fixed_iops @fixed_iops end |
#iops_per_tb ⇒ Google::Apis::FileV1beta1::IopsPerTb
IOPS per TB. Filestore defines TB as 1024^4 bytes (TiB).
Corresponds to the JSON property iopsPerTb
1771 1772 1773 |
# File 'lib/google/apis/file_v1beta1/classes.rb', line 1771 def iops_per_tb @iops_per_tb end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1778 1779 1780 1781 |
# File 'lib/google/apis/file_v1beta1/classes.rb', line 1778 def update!(**args) @fixed_iops = args[:fixed_iops] if args.key?(:fixed_iops) @iops_per_tb = args[:iops_per_tb] if args.key?(:iops_per_tb) end |