Class: Google::Apis::FileV1beta1::PromoteReplicaRequest
- Inherits:
-
Object
- Object
- Google::Apis::FileV1beta1::PromoteReplicaRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/file_v1beta1/classes.rb,
lib/google/apis/file_v1beta1/representations.rb,
lib/google/apis/file_v1beta1/representations.rb
Overview
PromoteReplicaRequest promotes a Filestore standby instance (replica).
Instance Attribute Summary collapse
-
#peer_instance ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PromoteReplicaRequest
constructor
A new instance of PromoteReplicaRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PromoteReplicaRequest
Returns a new instance of PromoteReplicaRequest.
1839 1840 1841 |
# File 'lib/google/apis/file_v1beta1/classes.rb', line 1839 def initialize(**args) update!(**args) end |
Instance Attribute Details
#peer_instance ⇒ String
Optional. The resource name of the peer instance to promote, in the format
projects/project_id/locations/location_id/instances/instance_id`. The
peer instance is required if the operation is called on an active instance.
Corresponds to the JSON propertypeerInstance`
1837 1838 1839 |
# File 'lib/google/apis/file_v1beta1/classes.rb', line 1837 def peer_instance @peer_instance end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1844 1845 1846 |
# File 'lib/google/apis/file_v1beta1/classes.rb', line 1844 def update!(**args) @peer_instance = args[:peer_instance] if args.key?(:peer_instance) end |