Class: Google::Apis::FileV1beta1::ReplicaConfig
- Inherits:
-
Object
- Object
- Google::Apis::FileV1beta1::ReplicaConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/file_v1beta1/classes.rb,
lib/google/apis/file_v1beta1/representations.rb,
lib/google/apis/file_v1beta1/representations.rb
Overview
Replica configuration for the instance.
Instance Attribute Summary collapse
-
#last_active_sync_time ⇒ String
Output only.
-
#peer_instance ⇒ String
The name of the source instance for the replica, in the format
projects/project/locations/location/instances/instance``. -
#state ⇒ String
Output only.
-
#state_reasons ⇒ Array<String>
Output only.
-
#state_update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReplicaConfig
constructor
A new instance of ReplicaConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReplicaConfig
Returns a new instance of ReplicaConfig.
1903 1904 1905 |
# File 'lib/google/apis/file_v1beta1/classes.rb', line 1903 def initialize(**args) update!(**args) end |
Instance Attribute Details
#last_active_sync_time ⇒ String
Output only. The timestamp of the latest replication snapshot taken on the
active instance and is already replicated safely.
Corresponds to the JSON property lastActiveSyncTime
1879 1880 1881 |
# File 'lib/google/apis/file_v1beta1/classes.rb', line 1879 def last_active_sync_time @last_active_sync_time end |
#peer_instance ⇒ String
The name of the source instance for the replica, in the format projects/
project/locations/location/instances/instance`. This field is required
when creating a replica.
Corresponds to the JSON propertypeerInstance`
1886 1887 1888 |
# File 'lib/google/apis/file_v1beta1/classes.rb', line 1886 def peer_instance @peer_instance end |
#state ⇒ String
Output only. The replica state.
Corresponds to the JSON property state
1891 1892 1893 |
# File 'lib/google/apis/file_v1beta1/classes.rb', line 1891 def state @state end |
#state_reasons ⇒ Array<String>
Output only. Additional information about the replication state, if available.
Corresponds to the JSON property stateReasons
1896 1897 1898 |
# File 'lib/google/apis/file_v1beta1/classes.rb', line 1896 def state_reasons @state_reasons end |
#state_update_time ⇒ String
Output only. The time when the replica state was updated.
Corresponds to the JSON property stateUpdateTime
1901 1902 1903 |
# File 'lib/google/apis/file_v1beta1/classes.rb', line 1901 def state_update_time @state_update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1908 1909 1910 1911 1912 1913 1914 |
# File 'lib/google/apis/file_v1beta1/classes.rb', line 1908 def update!(**args) @last_active_sync_time = args[:last_active_sync_time] if args.key?(:last_active_sync_time) @peer_instance = args[:peer_instance] if args.key?(:peer_instance) @state = args[:state] if args.key?(:state) @state_reasons = args[:state_reasons] if args.key?(:state_reasons) @state_update_time = args[:state_update_time] if args.key?(:state_update_time) end |