Class: Google::Apis::FileV1beta1::Replication

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/file_v1beta1/classes.rb,
lib/google/apis/file_v1beta1/representations.rb,
lib/google/apis/file_v1beta1/representations.rb

Overview

Optional. The configuration used to replicate an instance.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Replication

Returns a new instance of Replication.



1932
1933
1934
# File 'lib/google/apis/file_v1beta1/classes.rb', line 1932

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#replicasArray<Google::Apis::FileV1beta1::ReplicaConfig>

Replication configuration for the replica instance associated with this instance. Only a single replica is supported. Corresponds to the JSON property replicas



1924
1925
1926
# File 'lib/google/apis/file_v1beta1/classes.rb', line 1924

def replicas
  @replicas
end

#roleString

Output only. The replication role. When creating a new replica, this field must be set to STANDBY. Corresponds to the JSON property role

Returns:

  • (String)


1930
1931
1932
# File 'lib/google/apis/file_v1beta1/classes.rb', line 1930

def role
  @role
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1937
1938
1939
1940
# File 'lib/google/apis/file_v1beta1/classes.rb', line 1937

def update!(**args)
  @replicas = args[:replicas] if args.key?(:replicas)
  @role = args[:role] if args.key?(:role)
end