Class: Google::Apis::FileV1beta1::RestoreInstanceRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/file_v1beta1/classes.rb,
lib/google/apis/file_v1beta1/representations.rb,
lib/google/apis/file_v1beta1/representations.rb

Overview

RestoreInstanceRequest restores an existing instance's file share from a backup.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RestoreInstanceRequest

Returns a new instance of RestoreInstanceRequest.



1967
1968
1969
# File 'lib/google/apis/file_v1beta1/classes.rb', line 1967

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#file_shareString

Required. Name of the file share in the Filestore instance that the backup is being restored to. Corresponds to the JSON property fileShare

Returns:

  • (String)


1953
1954
1955
# File 'lib/google/apis/file_v1beta1/classes.rb', line 1953

def file_share
  @file_share
end

#source_backupString

The resource name of the backup, in the format projects/project_id/ locations/location_id/backups/backup_id`. Corresponds to the JSON propertysourceBackup`

Returns:

  • (String)


1959
1960
1961
# File 'lib/google/apis/file_v1beta1/classes.rb', line 1959

def source_backup
  @source_backup
end

#source_snapshotString

The resource name of the snapshot, in the format projects/project_id/ locations/location_id/snapshots/snapshot_id`. Corresponds to the JSON propertysourceSnapshot`

Returns:

  • (String)


1965
1966
1967
# File 'lib/google/apis/file_v1beta1/classes.rb', line 1965

def source_snapshot
  @source_snapshot
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1972
1973
1974
1975
1976
# File 'lib/google/apis/file_v1beta1/classes.rb', line 1972

def update!(**args)
  @file_share = args[:file_share] if args.key?(:file_share)
  @source_backup = args[:source_backup] if args.key?(:source_backup)
  @source_snapshot = args[:source_snapshot] if args.key?(:source_snapshot)
end