Class: Google::Apis::FileV1beta1::Schedule
- Inherits:
-
Object
- Object
- Google::Apis::FileV1beta1::Schedule
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/file_v1beta1/classes.rb,
lib/google/apis/file_v1beta1/representations.rb,
lib/google/apis/file_v1beta1/representations.rb
Overview
Configure the schedule.
Instance Attribute Summary collapse
-
#day ⇒ String
Allows to define schedule that runs specified day of the week.
-
#duration ⇒ String
Output only.
-
#start_time ⇒ Google::Apis::FileV1beta1::TimeOfDay
Represents a time of day.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Schedule
constructor
A new instance of Schedule.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Schedule
Returns a new instance of Schedule.
2035 2036 2037 |
# File 'lib/google/apis/file_v1beta1/classes.rb', line 2035 def initialize(**args) update!(**args) end |
Instance Attribute Details
#day ⇒ String
Allows to define schedule that runs specified day of the week.
Corresponds to the JSON property day
2021 2022 2023 |
# File 'lib/google/apis/file_v1beta1/classes.rb', line 2021 def day @day end |
#duration ⇒ String
Output only. Duration of the time window, set by service producer.
Corresponds to the JSON property duration
2026 2027 2028 |
# File 'lib/google/apis/file_v1beta1/classes.rb', line 2026 def duration @duration end |
#start_time ⇒ Google::Apis::FileV1beta1::TimeOfDay
Represents a time of day. The date and time zone are either not significant or
are specified elsewhere. An API may choose to allow leap seconds. Related
types are google.type.Date and google.protobuf.Timestamp.
Corresponds to the JSON property startTime
2033 2034 2035 |
# File 'lib/google/apis/file_v1beta1/classes.rb', line 2033 def start_time @start_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2040 2041 2042 2043 2044 |
# File 'lib/google/apis/file_v1beta1/classes.rb', line 2040 def update!(**args) @day = args[:day] if args.key?(:day) @duration = args[:duration] if args.key?(:duration) @start_time = args[:start_time] if args.key?(:start_time) end |