Class: Google::Apis::FileV1beta1::Schedule

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/file_v1beta1/classes.rb,
lib/google/apis/file_v1beta1/representations.rb,
lib/google/apis/file_v1beta1/representations.rb

Overview

Configure the schedule.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Schedule

Returns a new instance of Schedule.



2036
2037
2038
# File 'lib/google/apis/file_v1beta1/classes.rb', line 2036

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dayString

Allows to define schedule that runs specified day of the week. Corresponds to the JSON property day

Returns:

  • (String)


2022
2023
2024
# File 'lib/google/apis/file_v1beta1/classes.rb', line 2022

def day
  @day
end

#durationString

Output only. Duration of the time window, set by service producer. Corresponds to the JSON property duration

Returns:

  • (String)


2027
2028
2029
# File 'lib/google/apis/file_v1beta1/classes.rb', line 2027

def duration
  @duration
end

#start_timeGoogle::Apis::FileV1beta1::TimeOfDay

Represents a time of day. The date and time zone are either not significant or are specified elsewhere. An API may choose to allow leap seconds. Related types are google.type.Date and google.protobuf.Timestamp. Corresponds to the JSON property startTime



2034
2035
2036
# File 'lib/google/apis/file_v1beta1/classes.rb', line 2034

def start_time
  @start_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2041
2042
2043
2044
2045
# File 'lib/google/apis/file_v1beta1/classes.rb', line 2041

def update!(**args)
  @day = args[:day] if args.key?(:day)
  @duration = args[:duration] if args.key?(:duration)
  @start_time = args[:start_time] if args.key?(:start_time)
end