Class: Google::Apis::FileV1beta1::Snapshot
- Inherits:
-
Object
- Object
- Google::Apis::FileV1beta1::Snapshot
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/file_v1beta1/classes.rb,
lib/google/apis/file_v1beta1/representations.rb,
lib/google/apis/file_v1beta1/representations.rb
Overview
A Filestore snapshot.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
A description of the snapshot with 2048 characters or less.
-
#filesystem_used_bytes ⇒ Fixnum
Output only.
-
#labels ⇒ Hash<String,String>
Resource labels to represent user provided metadata.
-
#name ⇒ String
Output only.
-
#state ⇒ String
Output only.
-
#tags ⇒ Hash<String,String>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Snapshot
constructor
A new instance of Snapshot.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Snapshot
Returns a new instance of Snapshot.
2171 2172 2173 |
# File 'lib/google/apis/file_v1beta1/classes.rb', line 2171 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The time when the snapshot was created.
Corresponds to the JSON property createTime
2129 2130 2131 |
# File 'lib/google/apis/file_v1beta1/classes.rb', line 2129 def create_time @create_time end |
#description ⇒ String
A description of the snapshot with 2048 characters or less. Requests with
longer descriptions will be rejected.
Corresponds to the JSON property description
2135 2136 2137 |
# File 'lib/google/apis/file_v1beta1/classes.rb', line 2135 def description @description end |
#filesystem_used_bytes ⇒ Fixnum
Output only. The amount of bytes needed to allocate a full copy of the
snapshot content
Corresponds to the JSON property filesystemUsedBytes
2141 2142 2143 |
# File 'lib/google/apis/file_v1beta1/classes.rb', line 2141 def filesystem_used_bytes @filesystem_used_bytes end |
#labels ⇒ Hash<String,String>
Resource labels to represent user provided metadata.
Corresponds to the JSON property labels
2146 2147 2148 |
# File 'lib/google/apis/file_v1beta1/classes.rb', line 2146 def labels @labels end |
#name ⇒ String
Output only. The resource name of the snapshot, in the format projects/
project_id/locations/location_id/instances/instance_id/snapshots/
snapshot_id`.
Corresponds to the JSON propertyname`
2153 2154 2155 |
# File 'lib/google/apis/file_v1beta1/classes.rb', line 2153 def name @name end |
#state ⇒ String
Output only. The snapshot state.
Corresponds to the JSON property state
2158 2159 2160 |
# File 'lib/google/apis/file_v1beta1/classes.rb', line 2158 def state @state end |
#tags ⇒ Hash<String,String>
Optional. Input only. Immutable. Tag key-value pairs bound to this resource.
Each key must be a namespaced name and each value a short name. Example: "
123456789012/environment" : "production", "123456789013/costCenter" : "
marketing" See the documentation for more information: - Namespaced name:
https://cloud.google.com/resource-manager/docs/tags/tags-creating-and-managing#
retrieving_tag_key - Short name: https://cloud.google.com/resource-manager/
docs/tags/tags-creating-and-managing#retrieving_tag_value
Corresponds to the JSON property tags
2169 2170 2171 |
# File 'lib/google/apis/file_v1beta1/classes.rb', line 2169 def @tags end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2176 2177 2178 2179 2180 2181 2182 2183 2184 |
# File 'lib/google/apis/file_v1beta1/classes.rb', line 2176 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @filesystem_used_bytes = args[:filesystem_used_bytes] if args.key?(:filesystem_used_bytes) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @state = args[:state] if args.key?(:state) @tags = args[:tags] if args.key?(:tags) end |