Class: Google::Apis::FileV1beta1::TimeOfDay
- Inherits:
-
Object
- Object
- Google::Apis::FileV1beta1::TimeOfDay
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/file_v1beta1/classes.rb,
lib/google/apis/file_v1beta1/representations.rb,
lib/google/apis/file_v1beta1/representations.rb
Overview
Represents a time of day. The date and time zone are either not significant or
are specified elsewhere. An API may choose to allow leap seconds. Related
types are google.type.Date and google.protobuf.Timestamp.
Instance Attribute Summary collapse
-
#hours ⇒ Fixnum
Hours of a day in 24 hour format.
-
#minutes ⇒ Fixnum
Minutes of an hour.
-
#nanos ⇒ Fixnum
Fractions of seconds, in nanoseconds.
-
#seconds ⇒ Fixnum
Seconds of a minute.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TimeOfDay
constructor
A new instance of TimeOfDay.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TimeOfDay
Returns a new instance of TimeOfDay.
2257 2258 2259 |
# File 'lib/google/apis/file_v1beta1/classes.rb', line 2257 def initialize(**args) update!(**args) end |
Instance Attribute Details
#hours ⇒ Fixnum
Hours of a day in 24 hour format. Must be greater than or equal to 0 and
typically must be less than or equal to 23. An API may choose to allow the
value "24:00:00" for scenarios like business closing time.
Corresponds to the JSON property hours
2236 2237 2238 |
# File 'lib/google/apis/file_v1beta1/classes.rb', line 2236 def hours @hours end |
#minutes ⇒ Fixnum
Minutes of an hour. Must be greater than or equal to 0 and less than or equal
to 59.
Corresponds to the JSON property minutes
2242 2243 2244 |
# File 'lib/google/apis/file_v1beta1/classes.rb', line 2242 def minutes @minutes end |
#nanos ⇒ Fixnum
Fractions of seconds, in nanoseconds. Must be greater than or equal to 0 and
less than or equal to 999,999,999.
Corresponds to the JSON property nanos
2248 2249 2250 |
# File 'lib/google/apis/file_v1beta1/classes.rb', line 2248 def nanos @nanos end |
#seconds ⇒ Fixnum
Seconds of a minute. Must be greater than or equal to 0 and typically must be
less than or equal to 59. An API may allow the value 60 if it allows leap-
seconds.
Corresponds to the JSON property seconds
2255 2256 2257 |
# File 'lib/google/apis/file_v1beta1/classes.rb', line 2255 def seconds @seconds end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2262 2263 2264 2265 2266 2267 |
# File 'lib/google/apis/file_v1beta1/classes.rb', line 2262 def update!(**args) @hours = args[:hours] if args.key?(:hours) @minutes = args[:minutes] if args.key?(:minutes) @nanos = args[:nanos] if args.key?(:nanos) @seconds = args[:seconds] if args.key?(:seconds) end |